@@ -327,16 +327,6 @@ class TestFoliumap(unittest.TestCase):
         out_str = m.to_html()
         assert "Countries" in out_str
 
-    def test_add_vector_tile_layer(self):
-        """Check adding vector tile layer"""
-        with self.assertRaises(NotImplementedError):
-            m = leafmap.Map()
-            url = "https://tile.nextzen.org/tilezen/vector/v1/512/all/{z}/{x}/{y}.mvt?api_key=gCZXZglvRQa6sB2z7JzL1w"
-            attribution = "Nextzen"
-            m.add_vector_tile_layer(url, attribution)
-            out_str = m.to_html()
-            assert "Nextzen" in out_str
-
     def test_add_wms_layer(self):
         """Check adding WMS layer"""
         m = leafmap.Map()
